.. CpGTools documentation master file, created by
   sphinx-quickstart on Wed Jul  3 16:33:43 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. toctree::
   :caption: CpGtools Documentation
   :numbered:
   :maxdepth: 2
   
   overview
   installation
   change_log


.. toctree::
   :caption: Data Format
   :numbered:
   :maxdepth: 2
   
   input_format

.. toctree::
   :caption: Test and Demo Datasets
   :numbered:
   :maxdepth: 2
   
   dataset
   
.. toctree::
   :caption: Usage Information
   :numbered:
   :glob:
   :maxdepth: 2
   
   demo/*


.. toctree::
   :caption: Compare Differential Analysis Tools
   :numbered:
   :maxdepth: 2
   
   compare_diff_tools

.. toctree::
   :caption: Liscense

   liscense

.. toctree::
   :caption: Reference

   reference

